Catch exceptions hook, line, and sinker.
fuck ai forever.
sinker is an attempt to write the smallest possible try/catch extension. it should be a seamless drop-in for existing code, and the extensions should be simple and obvious.
try+, the single public var, analyzes each form and outputs the associated code to handle them. it merges similar/overlapping catch clauses, uses cond or case where appropriate, and does its best to not waste cycles.
Catch exceptions hook, line, and sinker. fuck ai forever. sinker is an attempt to write the smallest possible try/catch extension. it should be a seamless drop-in for existing code, and the extensions should be simple and obvious. `try+`, the single public var, analyzes each form and outputs the associated code to handle them. it merges similar/overlapping `catch` clauses, uses `cond` or `case` where appropriate, and does its best to not waste cycles.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |