(split-vec vec idx)Returns a vector of the given vec split at idx. If idx is nil, returns [vec nil].
Returns a vector of the given vec split at `idx`. If `idx` is `nil`, returns [vec nil].
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |